pitchtools.calculate_harmonic_chromatic_interval
================================================

.. autofunction:: abjad.tools.pitchtools.calculate_harmonic_chromatic_interval.calculate_harmonic_chromatic_interval
   :noindex:
